#pragma once

#include "genericConfiguration.h"

class AuditConfiguration : public GenericLogModeConfiguration
{
    Q_OBJECT

public:
    AuditConfiguration();
};

